# searcheonet

Python package that allows users to search for information about natural events from the NASA EONET API

## Installation

```bash
$ pip install searcheonet
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`searcheonet` was created by Alan Shen. It is licensed under the terms of the Apache License 2.0 license.

## Credits

`searcheonet` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
